# - Config to retrieve all components of the gz-sim9 package
#
# This should only be invoked by gz-sim9-config.cmake.
#
# To retrieve this meta-package, use:
# find_package(gz-sim9 COMPONENTS all)
#
# This creates the target gz-sim9::all which will link to all known
# components of gz-sim9, including the core library.
#
# This also creates the variable gz-sim9_ALL_LIBRARIES
#
################################################################################

cmake_minimum_required(VERSION 3.22.1 FATAL_ERROR)

if(gz-sim9_ALL_CONFIG_INCLUDED)
  return()
endif()
set(gz-sim9_ALL_CONFIG_INCLUDED TRUE)

if(NOT gz-sim9-all_FIND_QUIETLY)
  message(STATUS "Looking for all libraries of gz-sim9 -- found version 9.0.0")
endif()


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was gz-all-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/x86_64-linux-gnu/cmake/gz-sim9-all" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Get access to the find_dependency utility
include(CMakeFindDependencyMacro)

# Find the core library
find_dependency(gz-sim9 9.0.0 EXACT)

# Find the component libraries
find_dependency(gz-sim9-rendering 9.0.0 EXACT)
find_dependency(gz-sim9-gui 9.0.0 EXACT)
find_dependency(gz-sim9-ackermann-steering-system 9.0.0 EXACT)
find_dependency(gz-sim9-acoustic-comms-system 9.0.0 EXACT)
find_dependency(gz-sim9-advanced-lift-drag-system 9.0.0 EXACT)
find_dependency(gz-sim9-air-pressure-system 9.0.0 EXACT)
find_dependency(gz-sim9-air-speed-system 9.0.0 EXACT)
find_dependency(gz-sim9-altimeter-system 9.0.0 EXACT)
find_dependency(gz-sim9-apply-joint-force-system 9.0.0 EXACT)
find_dependency(gz-sim9-apply-link-wrench-system 9.0.0 EXACT)
find_dependency(gz-sim9-linearbatteryplugin-system 9.0.0 EXACT)
find_dependency(gz-sim9-breadcrumbs-system 9.0.0 EXACT)
find_dependency(gz-sim9-buoyancy-system 9.0.0 EXACT)
find_dependency(gz-sim9-buoyancy-engine-system 9.0.0 EXACT)
find_dependency(gz-sim9-collada-world-exporter-system 9.0.0 EXACT)
find_dependency(gz-sim9-comms-endpoint-system 9.0.0 EXACT)
find_dependency(gz-sim9-contact-system 9.0.0 EXACT)
find_dependency(gz-sim9-camera-video-recorder-system 9.0.0 EXACT)
find_dependency(gz-sim9-detachable-joint-system 9.0.0 EXACT)
find_dependency(gz-sim9-diff-drive-system 9.0.0 EXACT)
find_dependency(gz-sim9-dvl-system 9.0.0 EXACT)
find_dependency(gz-sim9-elevator-system 9.0.0 EXACT)
find_dependency(gz-sim9-environment-preload-system 9.0.0 EXACT)
find_dependency(gz-sim9-environmental-sensor-system 9.0.0 EXACT)
find_dependency(gz-sim9-follow-actor-system 9.0.0 EXACT)
find_dependency(gz-sim9-forcetorque-system 9.0.0 EXACT)
find_dependency(gz-sim9-hydrodynamics-system 9.0.0 EXACT)
find_dependency(gz-sim9-imu-system 9.0.0 EXACT)
find_dependency(gz-sim9-joint-controller-system 9.0.0 EXACT)
find_dependency(gz-sim9-joint-position-controller-system 9.0.0 EXACT)
find_dependency(gz-sim9-joint-state-publisher-system 9.0.0 EXACT)
find_dependency(gz-sim9-joint-trajectory-controller-system 9.0.0 EXACT)
find_dependency(gz-sim9-kinetic-energy-monitor-system 9.0.0 EXACT)
find_dependency(gz-sim9-label-system 9.0.0 EXACT)
find_dependency(gz-sim9-lens-flare-system 9.0.0 EXACT)
find_dependency(gz-sim9-lift-drag-system 9.0.0 EXACT)
find_dependency(gz-sim9-lighter_than_air_dynamics-system 9.0.0 EXACT)
find_dependency(gz-sim9-log-system 9.0.0 EXACT)
find_dependency(gz-sim9-log-video-recorder-system 9.0.0 EXACT)
find_dependency(gz-sim9-logicalaudiosensorplugin-system 9.0.0 EXACT)
find_dependency(gz-sim9-logical-camera-system 9.0.0 EXACT)
find_dependency(gz-sim9-magnetometer-system 9.0.0 EXACT)
find_dependency(gz-sim9-model-photo-shoot-system 9.0.0 EXACT)
find_dependency(gz-sim9-mecanum-drive-system 9.0.0 EXACT)
find_dependency(gz-sim9-multicopter-motor-model-system 9.0.0 EXACT)
find_dependency(gz-sim9-multicopter-control-system 9.0.0 EXACT)
find_dependency(gz-sim9-navsat-system 9.0.0 EXACT)
find_dependency(gz-sim9-odometry-publisher-system 9.0.0 EXACT)
find_dependency(gz-sim9-opticaltactileplugin-system 9.0.0 EXACT)
find_dependency(gz-sim9-particle-emitter-system 9.0.0 EXACT)
find_dependency(gz-sim9-performer-detector-system 9.0.0 EXACT)
find_dependency(gz-sim9-perfect-comms-system 9.0.0 EXACT)
find_dependency(gz-sim9-physics-system 9.0.0 EXACT)
find_dependency(gz-sim9-pose-publisher-system 9.0.0 EXACT)
find_dependency(gz-sim9-python-system-loader-system 9.0.0 EXACT)
find_dependency(gz-sim9-rf-comms-system 9.0.0 EXACT)
find_dependency(gz-sim9-scene-broadcaster-system 9.0.0 EXACT)
find_dependency(gz-sim9-sensors-system 9.0.0 EXACT)
find_dependency(gz-sim9-shader-param-system 9.0.0 EXACT)
find_dependency(gz-sim9-spacecraft-thruster-model-system 9.0.0 EXACT)
find_dependency(gz-sim9-thermal-system 9.0.0 EXACT)
find_dependency(gz-sim9-thermal-sensor-system 9.0.0 EXACT)
find_dependency(gz-sim9-thruster-system 9.0.0 EXACT)
find_dependency(gz-sim9-touchplugin-system 9.0.0 EXACT)
find_dependency(gz-sim9-track-controller-system 9.0.0 EXACT)
find_dependency(gz-sim9-tracked-vehicle-system 9.0.0 EXACT)
find_dependency(gz-sim9-trajectory-follower-system 9.0.0 EXACT)
find_dependency(gz-sim9-triggered-publisher-system 9.0.0 EXACT)
find_dependency(gz-sim9-user-commands-system 9.0.0 EXACT)
find_dependency(gz-sim9-velocity-control-system 9.0.0 EXACT)
find_dependency(gz-sim9-wheel-slip-system 9.0.0 EXACT)
find_dependency(gz-sim9-wind-effects-system 9.0.0 EXACT)
find_dependency(gz-sim9-gz 9.0.0 EXACT)

if(NOT TARGET gz-sim9::gz-sim9-all)
  include("${CMAKE_CURRENT_LIST_DIR}/gz-sim9-all-targets.cmake")

  add_library(gz-sim9::all INTERFACE IMPORTED)
  set_target_properties(gz-sim9::all PROPERTIES
    INTERFACE_LINK_LIBRARIES "gz-sim9::gz-sim9-all")

endif()

# Create the "requested" target if it does not already exist
if(NOT TARGET gz-sim9::requested)
  add_library(gz-sim9::requested INTERFACE IMPORTED)
endif()

# Link the "all" target to the "requested" target
get_target_property(gz_requested_components gz-sim9::requested INTERFACE_LINK_LIBRARIES)
if(NOT gz_requested_components)
  set_target_properties(gz-sim9::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "gz-sim9::gz-sim9-all")
else()
  set_target_properties(gz-sim9::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "${gz_requested_components};gz-sim9::gz-sim9-all")
endif()

set(gz-sim9_ALL_LIBRARIES gz-sim9::gz-sim9-all)
